@@ -39,7 +39,7 @@ targetLangs = ['es', 'pt']
 
 # Diretório fonte
 
-sourceDir = 'amostra' + '_'.join(sourceLang.split('-')).lower()
+sourceDir = 'amostra/' + '_'.join(sourceLang.split('-')).lower()
 
 # Preservação da sintaxe Markdown DocFX
 
@@ -175,25 +175,26 @@ def root():
     """Traslation of DocFX source code"""
     init()
     global workTree
-    if sourceDir.split('/')[0] not in os.listdir():
-        PrRed('\nPath "' + sourceDir.split('/')[0] + '" has not been found!')
-        exit()
-
-    if sourceDir.split('/')[1] not in os.listdir(sourceDir.split('/')[0]):
-        PrRed('\nPath "' + sourceDir + '" for source language has not been found!')
+    if sourceDir not in os.listdir():
+        PrRed('\nThe directory "' + sourceDir + '" for source files has not been found!')
         exit()
 
     for lang in targetLangs:
-        targetPaths.append(sourceDir.split('/')[0] + '/' + '_'.join(lang.split('-')).lower())
+        targetPaths.append('_'.join(lang.split('-')).lower())
 
     try:
-        repo = Repo(sourceDir.split('/')[0])
+        repo = Repo()
     except:
-        PrRed('Repository not found!\n Initialize a Git repo at "' + sourceDir.split('/')[0] + '" and make the first commit.')
+        PrRed("You aren't in a repository!\n Initialize a Git repo and make the first commit.")
         re.purge
         exit()
     modifiedUnstaged = repo.index.diff(None)
-    modifiedStaged = repo.index.diff('HEAD')
+    try:
+        modifiedStaged = repo.index.diff('HEAD')
+    except:
+        PrRed("HEAD could not be found!\n Please make the first commit.")
+        re.purge
+        exit()
     allModified = modifiedStaged + modifiedUnstaged
     workTree = [n.a_blob.path for n in allModified if n.a_blob.path.split('/')[0] == '_'.join(sourceLang.split('-')).lower()] + repo.untracked_files
 
@@ -201,14 +202,17 @@ def root():
 
 @root.command()
 def diff():
+    """Translation of modified files (work tree)"""
+    global reqs
+    global chars
     if workTree:
         PrYellow('\n The following files will be added or overwritten in target languages:')
         for doc in workTree:
-            if doc.split('/')[-1] in os.listdir(sourceDir + '/' + '/'.join(doc.split('/')[1:-1])):
-                stats.append(FileStats(sourceDir.split('/')[0] + '/' + doc))
-                PrLightPurple(sourceDir.split('/')[0] + '/' + doc)
+            if doc.split('/')[-1] in os.listdir('/'.join(doc.split('/')[1:-1])):
+                stats.append(FileStats(doc))
+                PrLightPurple(doc)
             else:
-                PrYellow(sourceDir.split('/')[0] + '/' + doc + ' will be deleted in target languages.')
+                PrYellow(doc + ' will be deleted in target languages.')
         fls = list(filter(lambda x: x is not None, stats))
         for i in range(len(fls)):
             reqs += fls[i][0]
@@ -221,8 +225,8 @@ def diff():
         cont = input('\n Continue [c] or abort [Enter]? ')
         if cont == 'c':
             for doc in workTree:
-                if doc.split('/')[-1] in os.listdir(sourceDir + '/' + '/'.join(doc.split('/')[1:-1])):
-                    ProcessFiles(sourceDir.split('/')[0] + '/' + doc)
+                if doc.split('/')[-1] in os.listdir('/'.join(doc.split('/')[1:-1])):
+                    ProcessFiles(doc)
                 else:
                     for path in targetPaths:
                         try:
@@ -237,8 +241,11 @@ def diff():
 
 @root.command()
 def all():
+    """Translation of the entire DocFX project"""
     global processed
     global greenFlag
+    global reqs
+    global chars
     while not processed:
         if greenFlag:
             for item in Path(sourceDir.split('/')[0]).iterdir():
